

/**************************************************************************
** 
** File name   : publicchoice2009_schneider.do
** Date        : July 1, 2009
** Author      : Christina J. Schneider (christina.j.schneider@gmail.com)
** Purpose     : Estimate the panel models
** Requires    : publicchoice2009.dta 
** Output      : publicchoice2009.log 
**
**************************************************************************/
version 10.0

set more off
cd "C:\Users\schneiderle\Documents\Work\Projects\2009\Fiscal Opportunism\data\replication"
use publicchoice2009, replace
log using publicchoice2009, replace


/*
drop miss*
egen miss1=rowmiss(deficit_growth preelectionyear inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate unification oil1 oil2)
egen miss2=rowmiss(spending_growth preelectionyear inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate unification oil1 oil2)
egen miss3=rowmiss(socialsecurity_growth preelectionyear inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate unification oil1 oil2 )
*/



****************
****Figure 1****
****************

twoway (line education_growth year, sort) if land=="Bremen"&year>1974, xlabel(1975(5)2000) xline(1978 1994 1986 1982 1998 1990 2002, lpattern(dash)) xtitle("Year") ytitle("Education Spending Growth") legend(off) scheme(s1mono) 


***************
****Table 1****
***************

**Model 1**

xtfevd deficit_growth preelec_franz inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate unification oil1 oil2 trend   if miss1==0, invariant(citystate ) pcse ar1
estimates store m1

**Model 2**

xtfevd deficit_growth preelec_franz preclose share_gov inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate unification oil1 oil2 trend   if miss1==0, invariant(citystate ) pcse ar1
estimates store m2

**Conditional Effects for Model 2 in Table 2**

interact preelec_franz preclose, cond(share_gov) val(47.9)
interact preelec_franz preclose, cond(share_gov) val(49.2)
interact preelec_franz preclose, cond(share_gov) val(50.9)
interact preelec_franz preclose, cond(share_gov) val(53.9)
interact preelec_franz preclose, cond(share_gov) val(58.3)

**Model 3**

xtfevd deficit_growth preelec_franz maastricht preelec_maastricht inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate oil1 oil2 trend   if miss1==0, invariant(citystate ) pcse ar1
estimates store m3

interact preelec_franz preelec_maastricht, cond(maastricht) val(0)
interact preelec_franz preelec_maastricht, cond(maastricht) val(1)

**Model 4**

xtfevd deficit_growth preelec_franz inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate unification oil1 oil2 government_spd government_fdp grandcoalition trend   if miss1==0, invariant(citystate ) pcse ar1
estimates store m4


outreg2 [m1 m2 m3 m4] using deficit.raw, bdec(3) replace label ctitle(Baseline Model, Partisan Model, Competition Model, Maastricht Model) word e(F) adjr2 alpha(0.05, 0.1)


***************
****Table 3****
***************

**Model 5**

xtfevd spending_growth preelec_franz inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate unification oil1 oil2 trend   if miss2==0, invariant(citystate ) pcse ar1
estimates store m5, title(Baseline)

**Model 6**
xtfevd spending_growth preelec_franz preclose share_gov inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate unification oil1 oil2 trend   if miss2==0, invariant(citystate ) pcse ar1
estimates store m6, title(Competition)

**Conditional Effects for Model 6 in Table 2**

interact preelec_franz preclose, cond(share_gov) val(47.9)
interact preelec_franz preclose, cond(share_gov) val(49.2)
interact preelec_franz preclose, cond(share_gov) val(50.9)
interact preelec_franz preclose, cond(share_gov) val(53.9)
interact preelec_franz preclose, cond(share_gov) val(58.3)

**Model 7**

xtfevd spending_growth preelec_franz maastricht preelec_maastricht inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate oil1 oil2 trend   if miss2==0, invariant(citystate ) pcse ar1
estimates store m7, title(Maastricht)

interact preelec_franz preelec_maastricht, cond(maastricht) val(0)
interact preelec_franz preelec_maastricht, cond(maastricht) val(1)

**Model 8**

xtfevd spending_growth preelec_franz inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate unification oil1 oil2 government_spd government_fdp grandcoalition trend   if miss2==0, invariant(citystate ) pcse ar1
estimates store m8, title(Partisan)

outreg2 [m5 m6 m7 m8] using spending.raw, bdec(3) replace label ctitle(Baseline Model, Partisan Model, Competition Model, Maastricht Model) word e(F) adjr2 alpha(0.05, 0.1)


****************
**** Table 4****
****************

**Model 9**

xtfevd socialsecurity_growth preelec_franz inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate unification oil1 oil2 trend   if miss3==0, invariant(citystate ) pcse ar1
estimates store m9, title(Baseline)

**Model 10**

xtfevd socialsecurity_growth preelec_franz preclose share_gov inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate unification oil1 oil2 trend   if miss3==0, invariant(citystate ) pcse ar1
estimates store m10, title(Competition)

**Conditional Effects for Model 10 in Table 2**

interact preelec_franz preclose, cond(share_gov) val(47.9)
interact preelec_franz preclose, cond(share_gov) val(49.2)
interact preelec_franz preclose, cond(share_gov) val(50.9)
interact preelec_franz preclose, cond(share_gov) val(53.9)
interact preelec_franz preclose, cond(share_gov) val(58.3)

**Model 11**

xtfevd socialsecurity_growth preelec_franz maastricht preelec_maastricht inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate oil1 oil2 trend   if miss3==0, invariant(citystate ) pcse ar1
estimates store m11, title(Maastricht)

interact preelec_franz preelec_maastricht, cond(maastricht) val(0)
interact preelec_franz preelec_maastricht, cond(maastricht) val(1)


**Model 12**

xtfevd socialsecurity_growth preelec_franz inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate unification oil1 oil2 government_spd government_fdp grandcoalition trend   if miss3==0, invariant(citystate ) pcse ar1
estimates store m12, title(Partisan)


outreg2 [m9 m10 m11 m12] using social.raw, bdec(3) replace label ctitle(Baseline Model, Partisan Model, Competition Model, Maastricht Model) word e(F) adjr2 alpha(0.05, 0.1)

log close
