
/**************************************************************************
** 
** File name   : publicchoice2009_webappendix.do
** Date        : July 1, 2009
** Author      : Christina J. Schneider (christina.j.schneider@gmail.com)
** Purpose     : Estimate the models in the appendices
** Requires    : publicchoice2009.dta 
** 
**************************************************************************/
version 10.0

set more off
cd "C:\Users\schneiderle\Documents\Work\Projects\2009\Fiscal Opportunism\data\replication"
use publicchoice2009, replace

**Appendix A1**

generate y = uniform()
quietly reg y deficit_growth spending_growth socialsecurity_growth maastricht share_gov government_spd government_fdp grandcoalition preelec_franz inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate unification oil1 oil2 trend, noconstant
estadd summ
esttab using summary.cvs, replace cells("N mean sd min max") nogap nomtitle nonumber
drop y



**Appendix A2**
xtfevd deficit_growth preelec_franz maastricht preelec_maastricht s_elec inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate unification oil1 oil2 trend   if miss1==0, invariant(citystate ) pcse ar1
estimates store elec1
xtfevd spending_growth preelec_franz maastricht preelec_maastricht s_elec inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate unification oil1 oil2 trend   if miss2==0, invariant(citystate ) pcse ar1
estimates store elec2
xtfevd socialsecurity_growth preelec_franz maastricht preelec_maastricht s_elec inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate unification oil1 oil2 trend   if miss3==0, invariant(citystate ) pcse ar1
estimates store elec3

outreg2 [elec1 elec2 elec3] using elec.raw, bdec(3) replace label ctitle(Deficit, Spending, Social Security) word e(F) adjr2 alpha(0.05, 0.1)


**Appendix A3**

xtfevd deficit_growth preelec_franz postelection maastricht preelec_maastricht inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate oil1 oil2 trend   if miss1==0, invariant(citystate ) pcse ar1
estimates store postelec1
xtfevd spending_growth preelec_franz postelection maastricht preelec_maastricht inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate oil1 oil2 trend   if miss2==0, invariant(citystate ) pcse ar1
estimates store postelec2
xtfevd socialsecurity_growth preelec_franz postelection maastricht preelec_maastricht inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate oil1 oil2 trend   if miss3==0, invariant(citystate ) pcse ar1
estimates store postelec3

outreg2 [postelec1 postelec2 postelec3] using postelec.raw, bdec(3) replace label ctitle(Baseline Model, Partisan Model, Competition Model, Maastricht Model) word e(F) adjr2 alpha(0.05, 0.1)


**Appendix A4**


*Note: spd, gruene, fdp coalitions coded into spdgruene
xtfevd deficit_growth preelec_franz maastricht preelec_maastricht inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate unification oil1 oil2 trend spd spdfdp cdufdp spdgruene grandcoalition if miss1==0, invariant(citystate ) pcse ar1
estimates store partisan1
xtfevd spending_growth preelec_franz maastricht preelec_maastricht  inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate unification oil1 oil2 trend spd spdfdp cdufdp spdgruene grandcoalition if miss2==0, invariant(citystate ) pcse ar1
estimates store partisan2
xtfevd socialsecurity_growth preelec_franz maastricht preelec_maastricht inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate unification oil1 oil2 trend spd spdfdp cdufdp spdgruene grandcoalition if miss3==0, invariant(citystate ) pcse ar1
estimates store partisan3

*Note: spd, gruene, fdp coalitions coded into spdfdp => results do not change!
xtfevd deficit_growth preelec_franz maastricht preelec_maastricht inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate unification oil1 oil2 trend spd spdfdp2 cdufdp spdgruene2 grandcoalition if miss1==0, invariant(citystate ) pcse ar1
estimates store partisan1a
xtfevd spending_growth preelec_franz maastricht preelec_maastricht inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate unification oil1 oil2 trend spd spdfdp2 cdufdp spdgruene2 grandcoalition if miss2==0, invariant(citystate ) pcse ar1
estimates store partisan2a
xtfevd socialsecurity_growth preelec_franz maastricht preelec_maastricht inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate unification oil1 oil2 trend spd spdfdp2 cdufdp spdgruene2 grandcoalition if miss3==0, invariant(citystate ) pcse ar1
estimates store partisan3a

outreg2 [partisan1 partisan2 partisan3] using partisan1.raw, bdec(3) replace label ctitle(Baseline Model, Partisan Model, Competition Model, Maastricht Model) word e(F) adjr2 alpha(0.05, 0.1)
outreg2 [partisan1a partisan2a partisan3a] using partisan2.raw, bdec(3) replace label ctitle(Deficit, Spending, Social Security) word e(F) adjr2 alpha(0.05, 0.1)

**Appendix A5**

xtfevd deficit_growth preelec_franz maastricht preelec_maastricht inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate unification oil1 oil2 government_spd government_fdp grandcoalition fed_spdfdp fedgov_spd trend   if miss1==0, invariant(citystate ) pcse ar1
estimates store fed1
xtfevd spending_growth preelec_franz maastricht preelec_maastricht inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate unification oil1 oil2 government_spd government_fdp grandcoalition fed_spdfdp fedgov_spd trend   if miss2==0, invariant(citystate ) pcse ar1
estimates store fed2
xtfevd socialsecurity_growth preelec_franz maastricht preelec_maastricht inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate unification oil1 oil2 government_spd government_fdp grandcoalition fed_spdfdp fedgov_spd trend   if miss3==0, invariant(citystate ) pcse ar1
estimates store fed3

outreg2 [fed1 fed2 fed3] using fedpartisan.raw, bdec(3) replace label ctitle(Deficit, Spending, Social Security) word e(F) adjr2 alpha(0.05, 0.1)


**Appendix A6**

xtfevd deficit_growth preelec_franz preelec_spd inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate unification oil1 oil2 government_spd government_fdp grandcoalition trend   if miss1==0, invariant(citystate ) pcse ar1
estimates store partopp1

interact preelec_franz preelec_spd, cond(government_spd) val(0)
interact preelec_franz preelec_spd, cond(government_spd) val(1)


xtfevd spending_growth preelec_franz preelec_spd inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate unification oil1 oil2 government_spd government_fdp grandcoalition trend   if miss2==0, invariant(citystate ) pcse ar1
estimates store partopp2

interact preelec_franz preelec_spd, cond(government_spd) val(0)
interact preelec_franz preelec_spd, cond(government_spd) val(1)


xtfevd socialsecurity_growth preelec_franz preelec_spd inflation_ln totempl_ln_lag gdpcon_growth_ln_lag citystate unification oil1 oil2 government_spd government_fdp grandcoalition trend   if miss3==0, invariant(citystate ) pcse ar1
estimates store partopp3
interact preelec_franz preelec_spd, cond(government_spd) val(0)
interact preelec_franz preelec_spd, cond(government_spd) val(1)


outreg2 [partopp1 partopp2 partopp3] using partopp.raw, bdec(3) replace label ctitle(Deficit, Spending, Social Security) word e(F) adjr2 alpha(0.05, 0.1)


